@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,21 +7,23 @@
 #ifndef GRAVATARUPDATEWIDGET_H
 #define GRAVATARUPDATEWIDGET_H
 
-#include <QWidget>
 #include <QUrl>
+#include <QWidget>
 class QLabel;
 class QPushButton;
 
-namespace Gravatar {
+namespace Gravatar
+{
 class GravatarResolvUrlJob;
 }
-namespace KABGravatar {
+namespace KABGravatar
+{
 class GravatarUpdateWidget : public QWidget
 {
     Q_OBJECT
 public:
     explicit GravatarUpdateWidget(QWidget *parent = nullptr);
-    ~GravatarUpdateWidget();
+    ~GravatarUpdateWidget() override;
 
     void setEmail(const QString &email);
     QPixmap pixmap() const;
