@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -14,7 +14,7 @@ class MergeContactsDialogTest : public QObject
     Q_OBJECT
 public:
     explicit MergeContactsDialogTest(QObject *parent = nullptr);
-    ~MergeContactsDialogTest();
+    ~MergeContactsDialogTest() override;
 private Q_SLOTS:
     void shouldHaveDefaultValue();
     void shouldSwithStackedWidget();
