@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -14,7 +14,7 @@ class MergeContactWidgetListTest : public QObject
     Q_OBJECT
 public:
     explicit MergeContactWidgetListTest(QObject *parent = nullptr);
-    ~MergeContactWidgetListTest();
+    ~MergeContactWidgetListTest() override;
 private Q_SLOTS:
     void shouldHaveDefaultValue();
     void shouldCleanListWhenSetItems();
