@@ -1,7 +1,7 @@
 /*
   This file is part of KAddressBook.
 
-  SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
   based on code from SPDX-FileCopyrightText: 2014 Clément Vannier <clement.vannier@free.fr>
 
   SPDX-License-Identifier: GPL-2.0-or-later
@@ -15,14 +15,15 @@
 #include <QStringList>
 
 class KJob;
-namespace KABMailSender {
+namespace KABMailSender
+{
 class MailSenderJob : public QObject
 {
     Q_OBJECT
 
 public:
     explicit MailSenderJob(const Akonadi::Item::List &listItem, QObject *parent = nullptr);
-    ~MailSenderJob();
+    ~MailSenderJob() override;
 
     void start();
 
