@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -19,7 +19,7 @@ public:
     void exec() override;
     void createAction(KActionCollection *ac) override;
     void setCurrentItems(const Akonadi::Item::List &items) override;
-    Q_REQUIRED_RESULT PimCommon::GenericPluginInterface::RequireTypes requires() const override;
+    Q_REQUIRED_RESULT PimCommon::GenericPluginInterface::RequireTypes requiresFeatures() const override;
     void updateActions(int numberOfSelectedItems, int numberOfSelectedCollections) override;
 
 private:
