@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2018-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2018-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -14,7 +14,7 @@ class MarkdownConfigureDialogTest : public QObject
     Q_OBJECT
 public:
     explicit MarkdownConfigureDialogTest(QObject *parent = nullptr);
-    ~MarkdownConfigureDialogTest() = default;
+    ~MarkdownConfigureDialogTest() override = default;
 };
 
 #endif // MARKDOWNCONFIGUREDIALOGTEST_H
