@@ -1,20 +1,20 @@
 /*
-    SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "markdowncreateimagewidget.h"
 #include <KLocalizedString>
-#include <QFormLayout>
-#include <QLineEdit>
 #include <QCheckBox>
+#include <QFormLayout>
 #include <QLabel>
+#include <QLineEdit>
 #include <QSpinBox>
 MarkdownCreateImageWidget::MarkdownCreateImageWidget(QWidget *parent)
     : QWidget(parent)
 {
-    auto *mainLayout = new QFormLayout(this);
+    auto mainLayout = new QFormLayout(this);
     mainLayout->setObjectName(QStringLiteral("mainlayout"));
     mainLayout->setContentsMargins({});
 
@@ -43,7 +43,7 @@ MarkdownCreateImageWidget::MarkdownCreateImageWidget(QWidget *parent)
 
     QWidget *sizeWidget = new QWidget;
     sizeWidget->setObjectName(QStringLiteral("sizeWidget"));
-    auto *sizeWidgetLayout = new QHBoxLayout(sizeWidget);
+    auto sizeWidgetLayout = new QHBoxLayout(sizeWidget);
     sizeWidgetLayout->setObjectName(QStringLiteral("sizeWidgetLayout"));
     sizeWidgetLayout->setContentsMargins({});
     mainLayout->addRow(sizeWidget);
