@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,15 +7,15 @@
 #ifndef MARKDOWNCREATELINKWIDGET_H
 #define MARKDOWNCREATELINKWIDGET_H
 
-#include <QWidget>
 #include "markdownlib_private_export.h"
+#include <QWidget>
 class QLineEdit;
 class LIBKMAILMARKDOWNPRIVATE_TESTS_EXPORT MarkdownCreateLinkWidget : public QWidget
 {
     Q_OBJECT
 public:
     explicit MarkdownCreateLinkWidget(QWidget *parent = nullptr);
-    ~MarkdownCreateLinkWidget();
+    ~MarkdownCreateLinkWidget() override;
     Q_REQUIRED_RESULT QString linkStr() const;
 
 Q_SIGNALS:
