@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,8 +7,8 @@
 #ifndef SHORTURLENGINEPLUGINMANAGER_H
 #define SHORTURLENGINEPLUGINMANAGER_H
 
-#include <QObject>
 #include "shorturl_export.h"
+#include <QObject>
 class ShortUrlEnginePlugin;
 class ShortUrlEnginePluginManagerPrivate;
 class SHORTURL_EXPORT ShortUrlEnginePluginManager : public QObject
@@ -16,11 +16,12 @@ class SHORTURL_EXPORT ShortUrlEnginePluginManager : public QObject
     Q_OBJECT
 public:
     explicit ShortUrlEnginePluginManager(QObject *parent = nullptr);
-    ~ShortUrlEnginePluginManager();
+    ~ShortUrlEnginePluginManager() override;
 
     QVector<ShortUrlEnginePlugin *> pluginsList() const;
 
     static ShortUrlEnginePluginManager *self();
+
 private:
     ShortUrlEnginePluginManagerPrivate *const d;
 };
