@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,11 +7,12 @@
 #ifndef QUICKTEXTMENU_H
 #define QUICKTEXTMENU_H
 
-#include <QObject>
 #include "quicktext_export.h"
 #include <MessageComposer/ConvertSnippetVariablesUtil>
+#include <QObject>
 class QMenu;
-namespace MessageComposer {
+namespace MessageComposer
+{
 class PluginComposerInterface;
 class ConvertSnippetVariableMenu;
 }
@@ -20,7 +21,7 @@ class QUICKTEXT_EXPORT QuickTextMenu : public QObject
     Q_OBJECT
 public:
     explicit QuickTextMenu(QWidget *parentWidget, QObject *parent = nullptr);
-    ~QuickTextMenu();
+    ~QuickTextMenu() override;
     QMenu *menu() const;
 
     void setPluginComposerInterface(MessageComposer::PluginComposerInterface *composerInterface);
@@ -28,6 +29,7 @@ public:
 Q_SIGNALS:
     void insertText(const QString &str);
     void insertVariable(MessageComposer::ConvertSnippetVariablesUtil::VariableType type);
+
 private:
     void initializeMenu();
     QWidget *const mParentWidget;
