@@ -1,23 +1,22 @@
 /*
-   SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
+#include "quicktextwidget.h"
 #include "quicktextmanager.h"
 #include "quicktexttreewidget.h"
-#include "quicktextwidget.h"
 #include <KLocalizedString>
-#include <QHBoxLayout>
+#include <KMessageBox>
 #include <MailCommon/SnippetWidget>
 #include <MailCommon/SnippetsModel>
-#include <QDebug>
-#include <KMessageBox>
+#include <QHBoxLayout>
 #include <QStackedWidget>
 
 QuickTextWidget::QuickTextWidget(QWidget *parent)
     : QWidget(parent)
 {
-    auto *mainLayout = new QHBoxLayout(this);
+    auto mainLayout = new QHBoxLayout(this);
     mainLayout->setObjectName(QStringLiteral("mainLayout"));
     mainLayout->setContentsMargins({});
 
@@ -42,8 +41,7 @@ QuickTextWidget::QuickTextWidget(QWidget *parent)
     connect(mTreeWidget, &QuicktextTreeWidget::editSnippet, this, &QuickTextWidget::editSnippet);
     connect(mTreeWidget, &QuicktextTreeWidget::addSnippetGroup, this, &QuickTextWidget::addSnippetGroup);
     connect(mTreeWidget, &QuicktextTreeWidget::editSnippetGroup, this, &QuickTextWidget::editSnippetGroup);
-    connect(mSnippetsManager->selectionModel(), &QItemSelectionModel::selectionChanged,
-            this, [this]() {
+    connect(mSnippetsManager->selectionModel(), &QItemSelectionModel::selectionChanged, this, [this]() {
         save();
         if (mSnippetsManager->selectionModel()->selectedIndexes().isEmpty()) {
             mStackedWidget->setCurrentWidget(mEmptyWidget);
@@ -142,9 +140,7 @@ void QuickTextWidget::editSnippet()
     mSnippetWidget->setText(mCurrentGroupIndex.data(MailCommon::SnippetsModel::TextRole).toString());
     mSnippetWidget->setKeyword(mCurrentGroupIndex.data(MailCommon::SnippetsModel::KeywordRole).toString());
     mSnippetWidget->setAttachment(mCurrentGroupIndex.data(MailCommon::SnippetsModel::AttachmentRole).toString());
-    mSnippetWidget->setKeySequence(
-        QKeySequence::fromString(
-            mCurrentGroupIndex.data(MailCommon::SnippetsModel::KeySequenceRole).toString()));
+    mSnippetWidget->setKeySequence(QKeySequence::fromString(mCurrentGroupIndex.data(MailCommon::SnippetsModel::KeySequenceRole).toString()));
     mSnippetWidget->setWasChanged(false);
 }
 
