@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -21,7 +21,7 @@ ZoomTextPluginEditor::~ZoomTextPluginEditor()
 
 MessageComposer::PluginEditorInterface *ZoomTextPluginEditor::createInterface(QObject *parent)
 {
-    auto *interface = new ZoomTextPluginEditorInterface(parent);
+    auto interface = new ZoomTextPluginEditorInterface(parent);
     return interface;
 }
 
