@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -34,7 +34,7 @@ private:
         Unknown = -1,
         ZoomReset = 0,
         ZoomIn,
-        ZoomOut
+        ZoomOut,
     };
     ZoomTextType mType = Unknown;
     ZoomLabel *mZoomLabelWidget = nullptr;
