@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,17 +7,17 @@
 #include "automaticaddcontactsconfiguretab.h"
 #include "automaticaddcontactstabwidget.h"
 
-#include <QHBoxLayout>
-#include <QTabWidget>
-#include <KSharedConfig>
-#include <QRegularExpression>
-#include <KIdentityManagement/IdentityManager>
 #include <KIdentityManagement/Identity>
+#include <KIdentityManagement/IdentityManager>
+#include <KSharedConfig>
+#include <QHBoxLayout>
+#include <QRegularExpression>
+#include <QTabWidget>
 
 AutomaticAddContactsConfigureTab::AutomaticAddContactsConfigureTab(QWidget *parent)
     : QWidget(parent)
 {
-    auto *mainLayout = new QHBoxLayout(this);
+    auto mainLayout = new QHBoxLayout(this);
     mainLayout->setObjectName(QStringLiteral("mainlayout"));
     mainLayout->setContentsMargins({});
     mTabWidget = new QTabWidget(this);
@@ -34,7 +34,7 @@ void AutomaticAddContactsConfigureTab::initTab(KIdentityManagement::IdentityMana
 {
     KIdentityManagement::IdentityManager::ConstIterator end = identityManager->end();
     for (KIdentityManagement::IdentityManager::ConstIterator it = identityManager->begin(); it != end; ++it) {
-        auto *w = new AutomaticAddContactsTabWidget(this);
+        auto w = new AutomaticAddContactsTabWidget(this);
         connect(w, &AutomaticAddContactsTabWidget::configureChanged, this, &AutomaticAddContactsConfigureTab::configureChanged);
         mTabWidget->addTab(w, QStringLiteral("%1 (%2)").arg((*it).identityName(), (*it).primaryEmailAddress()));
         w->setIdentity((*it).uoid());
