@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -14,7 +14,7 @@ class CheckBeforeSendPluginTest : public QObject
     Q_OBJECT
 public:
     explicit CheckBeforeSendPluginTest(QObject *parent = nullptr);
-    ~CheckBeforeSendPluginTest();
+    ~CheckBeforeSendPluginTest() override;
 private Q_SLOTS:
     void shouldHaveDefaultValue();
 };
