@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -16,10 +16,11 @@ class ConfirmAddressEmailEntryDialog : public QDialog
     Q_OBJECT
 public:
     explicit ConfirmAddressEmailEntryDialog(QWidget *parent = nullptr);
-    ~ConfirmAddressEmailEntryDialog() = default;
+    ~ConfirmAddressEmailEntryDialog() override = default;
 
     Q_REQUIRED_RESULT QString emails() const;
     void setValue(const QString &val);
+
 private:
     QDialogButtonBox *mButtons = nullptr;
     QLineEdit *mLineEdit = nullptr;
