@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -15,7 +15,7 @@ class ConfirmAddressWidget : public QWidget
     Q_OBJECT
 public:
     explicit ConfirmAddressWidget(QWidget *parent = nullptr);
-    ~ConfirmAddressWidget();
+    ~ConfirmAddressWidget() override;
 
     void setValidAddresses(const QStringList &addresses);
     void setInvalidAddresses(const QStringList &addresses);
