@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,10 +7,11 @@
 #ifndef GRAMMARRESULTTEXTEDIT_H
 #define GRAMMARRESULTTEXTEDIT_H
 
-#include <QTextEdit>
-#include "grammarerror.h"
 #include "grammarcommon_export.h"
-namespace MessageComposer {
+#include "grammarerror.h"
+#include <QTextEdit>
+namespace MessageComposer
+{
 class PluginGrammarAction;
 }
 class GRAMMARCOMMON_EXPORT GrammarResultTextEdit : public QTextEdit
@@ -31,11 +32,12 @@ Q_SIGNALS:
     void replaceText(const MessageComposer::PluginGrammarAction &act);
     void checkAgain();
     void closeChecker();
+
 private:
     Q_DISABLE_COPY(GrammarResultTextEdit)
     void slotReplaceWord(const MessageComposer::PluginGrammarAction &act, const QString &replacementWord);
     enum TextInfo {
-        ReplaceFormatInfo = QTextFormat::UserProperty + 1
+        ReplaceFormatInfo = QTextFormat::UserProperty + 1,
     };
     void slotOpenGrammarUrlInfo(const QString &url);
     void generalPaletteChanged();
