@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -21,7 +21,7 @@ AntiVirusPlugin::~AntiVirusPlugin()
 
 PimCommon::GenericPluginInterface *AntiVirusPlugin::createInterface(QObject *parent)
 {
-    auto *interface = new AntiVirusPluginInterface(parent);
+    auto interface = new AntiVirusPluginInterface(parent);
     return interface;
 }
 
