@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -14,7 +14,7 @@ class MailMergeDialogTest : public QObject
     Q_OBJECT
 public:
     explicit MailMergeDialogTest(QObject *parent = nullptr);
-    ~MailMergeDialogTest();
+    ~MailMergeDialogTest() override;
 private Q_SLOTS:
     void shouldHaveDefaultValue();
 };
