@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -7,23 +7,24 @@
 #ifndef CSVWIDGET_H
 #define CSVWIDGET_H
 
+#include "mailmergeplugin_private_export.h"
 #include <QWidget>
-
 class KUrlRequester;
 class QUrl;
-namespace MailMerge {
-class CsvWidget : public QWidget
+namespace MailMerge
+{
+class MAILMERGEPRIVATE_TESTS_EXPORT CsvWidget : public QWidget
 {
     Q_OBJECT
 public:
     explicit CsvWidget(QWidget *parent = nullptr);
-    ~CsvWidget();
+    ~CsvWidget() override;
 
     void setPath(const QUrl &path);
-    QUrl path() const;
+    Q_REQUIRED_RESULT QUrl path() const;
 
 private:
-    KUrlRequester *mCvsUrlRequester = nullptr;
+    KUrlRequester *const mCvsUrlRequester;
 };
 }
 
