@@ -1,12 +1,12 @@
 /*
-  SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
 
 #include "mailmergewidget.h"
-#include "../widgets/csvwidget.h"
 #include "../widgets/addressbookwidget.h"
+#include "../widgets/csvwidget.h"
 
 #include "attachmentlistwidget.h"
 
@@ -14,25 +14,29 @@
 #include <QComboBox>
 
 #include <QHBoxLayout>
-#include <QVBoxLayout>
 #include <QLabel>
 #include <QStackedWidget>
+#include <QVBoxLayout>
 
 using namespace MailMerge;
 
 MailMergeWidget::MailMergeWidget(QWidget *parent)
     : QWidget(parent)
+    , mSource(new QComboBox(this))
+    , mStackedWidget(new QStackedWidget(this))
+    , mCsvWidget(new MailMerge::CsvWidget(this))
+    , mAddressbookWidget(new MailMerge::AddressBookWidget(this))
 {
-    QVBoxLayout *vbox = new QVBoxLayout;
-    setLayout(vbox);
+    auto mainLayout = new QVBoxLayout(this);
+    mainLayout->setObjectName(QStringLiteral("mainLayout"));
 
-    QHBoxLayout *hbox = new QHBoxLayout;
-    vbox->addLayout(hbox);
+    auto hbox = new QHBoxLayout;
+    mainLayout->addLayout(hbox);
 
-    QLabel *lab = new QLabel(i18n("Source:"));
+    auto lab = new QLabel(i18n("Source:"), this);
+    lab->setObjectName(QStringLiteral("lab"));
     hbox->addWidget(lab);
 
-    mSource = new QComboBox;
     mSource->setObjectName(QStringLiteral("source"));
     mSource->addItem(i18n("Address Book"), AddressBook);
     mSource->addItem(i18n("CSV"), CSV);
@@ -41,31 +45,26 @@ MailMergeWidget::MailMergeWidget(QWidget *parent)
 
     hbox->addWidget(mSource);
 
-    mStackedWidget = new QStackedWidget;
     mStackedWidget->setObjectName(QStringLiteral("stackedwidget"));
-    vbox->addWidget(mStackedWidget);
+    mainLayout->addWidget(mStackedWidget);
 
-    mAddressbookWidget = new MailMerge::AddressBookWidget;
     mAddressbookWidget->setObjectName(QStringLiteral("addressbookwidget"));
     mStackedWidget->addWidget(mAddressbookWidget);
 
-    mCsvWidget = new MailMerge::CsvWidget;
     mCsvWidget->setObjectName(QStringLiteral("csvwidget"));
 
     mStackedWidget->addWidget(mCsvWidget);
 
-    lab = new QLabel(i18n("Attachment:"));
-    vbox->addWidget(lab);
+    lab = new QLabel(i18n("Attachment:"), this);
+    mainLayout->addWidget(lab);
 
-    PimCommon::SimpleStringListEditor::ButtonCode buttonCode
-        = static_cast<PimCommon::SimpleStringListEditor::ButtonCode>(PimCommon::SimpleStringListEditor::Add | PimCommon::SimpleStringListEditor::Remove | PimCommon::SimpleStringListEditor::Modify);
-    mAttachment = new AttachmentListWidget(this, buttonCode,
-                                           i18n("A&dd..."), i18n("Re&move"),
-                                           i18n("Mod&ify..."));
+    PimCommon::SimpleStringListEditor::ButtonCode buttonCode = static_cast<PimCommon::SimpleStringListEditor::ButtonCode>(
+        PimCommon::SimpleStringListEditor::Add | PimCommon::SimpleStringListEditor::Remove | PimCommon::SimpleStringListEditor::Modify);
+    mAttachment = new AttachmentListWidget(this, buttonCode, i18n("A&dd..."), i18n("Re&move"), i18n("Mod&ify..."));
     mAttachment->setObjectName(QStringLiteral("attachment-list"));
 
-    vbox->addWidget(mAttachment);
-    vbox->addStretch();
+    mainLayout->addWidget(mAttachment);
+    mainLayout->addStretch();
 }
 
 MailMergeWidget::~MailMergeWidget()
