@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -8,21 +8,21 @@
 #include <Akonadi/Contact/RecipientsPickerWidget>
 #include <KConfigGroup>
 #include <KLocalizedString>
+#include <KPluginFactory>
 #include <KSharedConfig>
 #include <PimCommonAkonadi/LdapSearchDialog>
-#include <QBoxLayout>
 #include <QDialogButtonBox>
-#include <QPushButton>
 #include <QLineEdit>
+#include <QPushButton>
 #include <QTreeView>
-#include <KPluginFactory>
+#include <QVBoxLayout>
 
 K_PLUGIN_CLASS_WITH_JSON(EmailAddressSelectionLdapDialog, "emailaddressselectionldapdialog.json")
 
 EmailAddressSelectionLdapDialog::EmailAddressSelectionLdapDialog(QWidget *parent, const QList<QVariant> &)
     : Akonadi::AbstractEmailAddressSelectionDialog(parent)
 {
-    auto *mainLayout = new QVBoxLayout(this);
+    auto mainLayout = new QVBoxLayout(this);
     mView = new Akonadi::RecipientsPickerWidget(true, nullptr, this);
     mainLayout->addWidget(mView);
     connect(mView->emailAddressSelectionWidget()->view(), &QTreeView::doubleClicked, this, &QDialog::accept);
