@@ -21,21 +21,19 @@ ThisDayInHistory::ThisDayInHistory()
 
 QString ThisDayInHistory::info() const
 {
-    return i18n("This plugin provides links to Wikipedia's "
-                "'This Day in History' pages.");
+    return i18n(
+        "This plugin provides links to Wikipedia's "
+        "'This Day in History' pages.");
 }
 
 Element::List ThisDayInHistory::createDayElements(const QDate &date)
 {
     Element::List elements;
 
-    StoredElement *element
-        = new StoredElement(QStringLiteral("Wikipedia link"), i18n("This day in history"));
+    StoredElement *element = new StoredElement(QStringLiteral("Wikipedia link"), i18n("This day in history"));
 
-    element->setUrl(
-        QUrl(i18nc("Localized Wikipedia website", "https://en.wikipedia.org/wiki/")
-             +date.toString(i18nc("Qt date format used by the localized Wikipedia",
-                                  "MMMM_d"))));
+    element->setUrl(QUrl(i18nc("Localized Wikipedia website", "https://en.wikipedia.org/wiki/")
+                         + date.toString(i18nc("Qt date format used by the localized Wikipedia", "MMMM_d"))));
 
     elements.append(element);
 
@@ -46,13 +44,10 @@ Element::List ThisDayInHistory::createMonthElements(const QDate &date)
 {
     Element::List elements;
 
-    StoredElement *element
-        = new StoredElement(QStringLiteral("Wikipedia link"), i18n("This month in history"));
+    StoredElement *element = new StoredElement(QStringLiteral("Wikipedia link"), i18n("This month in history"));
 
-    element->setUrl(
-        QUrl(i18nc("Localized Wikipedia website", "https://en.wikipedia.org/wiki/")
-             +date.toString(i18nc("Qt date format used by the localized Wikipedia",
-                                  "MMMM_yyyy"))));
+    element->setUrl(QUrl(i18nc("Localized Wikipedia website", "https://en.wikipedia.org/wiki/")
+                         + date.toString(i18nc("Qt date format used by the localized Wikipedia", "MMMM_yyyy"))));
 
     elements.append(element);
 
