@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -8,7 +8,8 @@
 #define REACTIONTOINVITATIONDIALOG_H
 
 #include <QDialog>
-namespace KPIMTextEdit {
+namespace KPIMTextEdit
+{
 class PlainTextEditorWidget;
 }
 
@@ -17,7 +18,7 @@ class ReactionToInvitationDialog : public QDialog
     Q_OBJECT
 public:
     explicit ReactionToInvitationDialog(QWidget *parent = nullptr);
-    ~ReactionToInvitationDialog();
+    ~ReactionToInvitationDialog() override;
 
     QString comment() const;
 
