@@ -6,8 +6,8 @@
 
 #include "gnupgwksmessagepart.h"
 
-#include <MimeTreeParser/BodyPart>
 #include <KMime/Content>
+#include <MimeTreeParser/BodyPart>
 
 GnuPGWKSMessagePart::GnuPGWKSMessagePart(MimeTreeParser::Interface::BodyPart *part)
     : MimeTreeParser::MessagePart(part->objectTreeParser(), QString())
@@ -55,11 +55,7 @@ GnuPGWKSMessagePart::ConfirmationType GnuPGWKSMessagePart::stringToType(const QS
 void GnuPGWKSMessagePart::parseContent(KMime::Content *node)
 {
     const auto text = QString::fromUtf8(node->decodedContent());
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-    const auto lines = text.split(QLatin1Char('\n'), QString::SkipEmptyParts);
-#else
     const auto lines = text.split(QLatin1Char('\n'), Qt::SkipEmptyParts);
-#endif
     // https://tools.ietf.org/id/draft-koch-openpgp-webkey-service-02.txt
     // sections 4.3 and 4.4
     for (const auto &line : lines) {
