@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,15 +7,15 @@
 #ifndef DKIMAUTHENTICATIONVERIFIEDSERVERDIALOG_H
 #define DKIMAUTHENTICATIONVERIFIEDSERVERDIALOG_H
 
-#include <QDialog>
 #include "dkimconfigure_private_export.h"
+#include <QDialog>
 class DKIMAuthenticationVerifiedServerWidget;
 class LIBDKIMVERIFYCONFIGURE_TESTS_EXPORT DKIMAuthenticationVerifiedServerDialog : public QDialog
 {
     Q_OBJECT
 public:
     explicit DKIMAuthenticationVerifiedServerDialog(QWidget *parent = nullptr);
-    ~DKIMAuthenticationVerifiedServerDialog();
+    ~DKIMAuthenticationVerifiedServerDialog() override;
 
 private:
     void slotAccepted();
