@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2018-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2018-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,8 +7,8 @@
 #ifndef DKIMCONFIGURETAB_H
 #define DKIMCONFIGURETAB_H
 
-#include <QWidget>
 #include "dkimconfigure_private_export.h"
+#include <QWidget>
 
 class QTabWidget;
 class DKIMGeneralWidget;
@@ -20,7 +20,7 @@ class LIBDKIMVERIFYCONFIGURE_TESTS_EXPORT DKIMConfigureTab : public QWidget
     Q_OBJECT
 public:
     explicit DKIMConfigureTab(QWidget *parent = nullptr);
-    ~DKIMConfigureTab();
+    ~DKIMConfigureTab() override;
 
     void loadSettings();
     void saveSettings();
