@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,15 +7,15 @@
 #ifndef EXPIREACCOUNTTRASHFOLDERCONFIGDIALOG_H
 #define EXPIREACCOUNTTRASHFOLDERCONFIGDIALOG_H
 
-#include <QDialog>
 #include "libexpireaccounttrashfolderconfig_export.h"
+#include <QDialog>
 class ExpireAccountTrashFolderConfigWidget;
 class LIBEXPIREACCOUNTTRASHFOLDERCONFIG_EXPORT ExpireAccountTrashFolderConfigDialog : public QDialog
 {
     Q_OBJECT
 public:
     explicit ExpireAccountTrashFolderConfigDialog(QWidget *parent = nullptr);
-    ~ExpireAccountTrashFolderConfigDialog();
+    ~ExpireAccountTrashFolderConfigDialog() override;
 
 private:
     void writeConfig();
