@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,11 +7,12 @@
 #ifndef FOLDERCONFIGURESETTINGSGENERALWIDGET_H
 #define FOLDERCONFIGURESETTINGSGENERALWIDGET_H
 
-#include <QWidget>
 #include "folderconfiguresettings_private_export.h"
 #include "folderconfiguresettingspagebase.h"
 #include <AkonadiCore/Collection>
-namespace MailCommon {
+#include <QWidget>
+namespace MailCommon
+{
 class CollectionGeneralWidget;
 }
 class LIBFOLDERCONFIGURESETTINGS_TESTS_EXPORT FolderConfigureSettingsGeneralWidget : public FolderConfigureSettingsPageBase
@@ -19,8 +20,9 @@ class LIBFOLDERCONFIGURESETTINGS_TESTS_EXPORT FolderConfigureSettingsGeneralWidg
     Q_OBJECT
 public:
     explicit FolderConfigureSettingsGeneralWidget(QWidget *parent = nullptr);
-    ~FolderConfigureSettingsGeneralWidget();
+    ~FolderConfigureSettingsGeneralWidget() override;
     void save(Akonadi::Collection &col);
+
 private:
     MailCommon::CollectionGeneralWidget *const mCollectionGeneralWidget;
 };
