@@ -1,12 +1,12 @@
 /*
-   SPDX-FileCopyrightText: 2018-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2018-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "gravatarconfiguresettingspluginwidget.h"
-#include <Gravatar/GravatarConfigureSettingsWidget>
 #include <Gravatar/GravatarCache>
+#include <Gravatar/GravatarConfigureSettingsWidget>
 #include <PimCommon/ConfigureImmutableWidgetUtils>
 
 #include <KLocalizedString>
@@ -20,7 +20,7 @@ using namespace PimCommon::ConfigureImmutableWidgetUtils;
 GravatarConfigureSettingsPluginWidget::GravatarConfigureSettingsPluginWidget(QWidget *parent)
     : MessageViewer::MessageViewerConfigureSettingsPluginWidget(parent)
 {
-    auto *mainLayout = new QVBoxLayout(this);
+    auto mainLayout = new QVBoxLayout(this);
     mainLayout->setObjectName(QStringLiteral("mainlayout"));
     mainLayout->setContentsMargins({});
 
