@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -13,7 +13,7 @@ class EventDateTimeWidgetTest : public QObject
     Q_OBJECT
 public:
     explicit EventDateTimeWidgetTest(QObject *parent = nullptr);
-    ~EventDateTimeWidgetTest();
+    ~EventDateTimeWidgetTest() override;
 
 private Q_SLOTS:
     void shouldHaveDefaultValue();
