@@ -1,17 +1,17 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "viewerplugincreateeventinterface.h"
-#include "eventedit.h"
 #include "createeventjob.h"
+#include "eventedit.h"
 #include <KLocalizedString>
 
 #include <KActionCollection>
-#include <QIcon>
 #include <QAction>
+#include <QIcon>
 #include <QLayout>
 
 using namespace MessageViewer;
@@ -33,8 +33,8 @@ ViewerPluginInterface::SpecificFeatureTypes ViewerPluginCreateEventInterface::fe
 
 void ViewerPluginCreateEventInterface::setText(const QString &text)
 {
-    Q_UNUSED(text);
-    //Nothing
+    Q_UNUSED(text)
+    // Nothing
 }
 
 QList<QAction *> ViewerPluginCreateEventInterface::actions() const
@@ -71,7 +71,7 @@ void ViewerPluginCreateEventInterface::createAction(KActionCollection *ac)
         act->setIconText(i18n("Create Event"));
         addHelpTextAction(act, i18n("Allows you to create a calendar Event"));
         ac->addAction(QStringLiteral("create_event"), act);
-        ac->setDefaultShortcut(act, QKeySequence(Qt::CTRL + Qt::Key_E));
+        ac->setDefaultShortcut(act, QKeySequence(Qt::CTRL | Qt::Key_E));
         connect(act, &QAction::triggered, this, &ViewerPluginCreateEventInterface::slotActivatePlugin);
         mAction.append(act);
     }
@@ -80,7 +80,7 @@ void ViewerPluginCreateEventInterface::createAction(KActionCollection *ac)
 EventEdit *ViewerPluginCreateEventInterface::widget()
 {
     if (!mEventEdit) {
-        auto *parentWidget = static_cast<QWidget *>(parent());
+        auto parentWidget = static_cast<QWidget *>(parent());
         mEventEdit = new EventEdit(parentWidget);
         connect(mEventEdit, &EventEdit::createEvent, this, &ViewerPluginCreateEventInterface::slotCreateEvent);
         mEventEdit->setObjectName(QStringLiteral("eventedit"));
@@ -92,6 +92,6 @@ EventEdit *ViewerPluginCreateEventInterface::widget()
 
 void ViewerPluginCreateEventInterface::slotCreateEvent(const KCalendarCore::Event::Ptr &eventPtr, const Akonadi::Collection &collection)
 {
-    auto *createJob = new CreateEventJob(eventPtr, collection, mMessageItem, this);
+    auto createJob = new CreateEventJob(eventPtr, collection, mMessageItem, this);
     createJob->start();
 }
