@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,14 +7,14 @@
 #ifndef VIEWERPLUGINEXTERNALSCRIPTPARSEARGUMENTTEST_H
 #define VIEWERPLUGINEXTERNALSCRIPTPARSEARGUMENTTEST_H
 
-#include <QObject>
 #include <KMime/Message>
+#include <QObject>
 class ViewerPluginExternalScriptParseArgumentTest : public QObject
 {
     Q_OBJECT
 public:
     explicit ViewerPluginExternalScriptParseArgumentTest(QObject *parent = nullptr);
-    ~ViewerPluginExternalScriptParseArgumentTest();
+    ~ViewerPluginExternalScriptParseArgumentTest() override;
 
 private:
     void initializeMessage(const KMime::Message::Ptr &msg);
