@@ -1,23 +1,23 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "viewerpluginexternaleditdialog.h"
 #include "viewerpluginexternaleditwidget.h"
-#include <KLocalizedString>
-#include <QDialogButtonBox>
-#include <QVBoxLayout>
-#include <QPushButton>
 #include <KConfigGroup>
+#include <KLocalizedString>
 #include <KSharedConfig>
+#include <QDialogButtonBox>
+#include <QPushButton>
+#include <QVBoxLayout>
 
 ViewerPluginExternalEditDialog::ViewerPluginExternalEditDialog(QWidget *parent)
     : QDialog(parent)
 {
     setWindowTitle(i18nc("@title:window", "Add or Modify External Script"));
-    auto *mainLayout = new QVBoxLayout(this);
+    auto mainLayout = new QVBoxLayout(this);
 
     mEditWidget = new ViewerPluginExternalEditWidget(this);
     mEditWidget->setObjectName(QStringLiteral("editwidget"));
