@@ -8,10 +8,11 @@
 #ifndef PIMCALENDARSMODEL_H
 #define PIMCALENDARSMODEL_H
 
-#include <QSortFilterProxyModel>
 #include <QSet>
+#include <QSortFilterProxyModel>
 
-namespace Akonadi {
+namespace Akonadi
+{
 class EntityTreeModel;
 }
 
@@ -20,7 +21,7 @@ class PimCalendarsModel : public QSortFilterProxyModel
     Q_OBJECT
 public:
     enum Roles {
-        DataRole = Qt::UserRole + 1
+        DataRole = Qt::UserRole + 1,
     };
 
     explicit PimCalendarsModel(QObject *parent = nullptr);
