@@ -1,15 +1,15 @@
 /*
-   SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "templateparseremailaddressrequesterakonaditest.h"
 #include "../templateparseremailaddressrequesterakonadi.h"
+#include <Akonadi/Contact/EmailAddressRequester>
 #include <QHBoxLayout>
 #include <QSignalSpy>
 #include <QTest>
-#include <Akonadi/Contact/EmailAddressRequester>
 
 TemplateParserEmailAddressRequesterAkonadiTest::TemplateParserEmailAddressRequesterAkonadiTest(QObject *parent)
     : QObject(parent)
@@ -33,9 +33,7 @@ void TemplateParserEmailAddressRequesterAkonadiTest::shouldAssignValue()
 {
     TemplateParserEmailAddressRequesterAkonadi w;
     auto *mLineEdit = w.findChild<Akonadi::EmailAddressRequester *>(QStringLiteral("EmailAddressRequester"));
-    const QString str{
-        QStringLiteral("foo")
-    };
+    const QString str{QStringLiteral("foo")};
     w.setText(str);
     QCOMPARE(w.text(), str);
     QCOMPARE(mLineEdit->text(), str);
@@ -45,9 +43,7 @@ void TemplateParserEmailAddressRequesterAkonadiTest::shouldClearValue()
 {
     TemplateParserEmailAddressRequesterAkonadi w;
     auto *mLineEdit = w.findChild<Akonadi::EmailAddressRequester *>(QStringLiteral("EmailAddressRequester"));
-    const QString str{
-        QStringLiteral("foo")
-    };
+    const QString str{QStringLiteral("foo")};
     w.setText(str);
     QCOMPARE(w.text(), str);
     w.clear();
