@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -14,7 +14,7 @@ class AdblockManagerTest : public QObject
     Q_OBJECT
 public:
     explicit AdblockManagerTest(QObject *parent = nullptr);
-    ~AdblockManagerTest();
+    ~AdblockManagerTest() override;
 private Q_SLOTS:
     void shouldHaveDefaultValue();
 };
