@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    This file originates from QupZilla - WebKit based browser
    SPDX-FileCopyrightText: 2014 David Rosca <nowrep@gmail.com>
@@ -10,22 +10,23 @@
 #ifndef ADBLOCKMATCHER_H
 #define ADBLOCKMATCHER_H
 
-#include <QUrl>
-#include <QObject>
-#include <QVector>
 #include "adblockrule.h"
 #include "adblocksearchtree.h"
+#include <QObject>
+#include <QUrl>
+#include <QVector>
 
 class QWebEngineUrlRequestInfo;
 
-namespace AdBlock {
+namespace AdBlock
+{
 class AdblockManager;
 class AdBlockMatcher : public QObject
 {
     Q_OBJECT
 public:
     explicit AdBlockMatcher(AdblockManager *manager);
-    ~AdBlockMatcher();
+    ~AdBlockMatcher() override;
 
     const AdBlockRule *match(const QWebEngineUrlRequestInfo &request, const QString &urlDomain, const QString &urlString) const;
 
