@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -13,7 +13,7 @@ class AdBlockResultTest : public QObject
     Q_OBJECT
 public:
     explicit AdBlockResultTest(QObject *parent = nullptr);
-    ~AdBlockResultTest();
+    ~AdBlockResultTest() override;
 
 private Q_SLOTS:
     void shouldHaveDefaultValue();
