@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -11,13 +11,14 @@
 
 class QComboBox;
 class QToolButton;
-namespace AdBlock {
+namespace AdBlock
+{
 class AdBlockAddSubscriptionDialog : public QDialog
 {
     Q_OBJECT
 public:
     explicit AdBlockAddSubscriptionDialog(const QStringList &excludeList, QWidget *parent = nullptr);
-    ~AdBlockAddSubscriptionDialog();
+    ~AdBlockAddSubscriptionDialog() override;
 
     void selectedList(QString &name, QString &url);
 
