@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,12 +7,14 @@
 #ifndef ADBLOCKBLOCKABLEITEMSWIDGET_H
 #define ADBLOCKBLOCKABLEITEMSWIDGET_H
 
-#include <QWidget>
 #include "adblocklib_export.h"
-namespace PimCommon {
+#include <QWidget>
+namespace PimCommon
+{
 class CustomTreeView;
 }
-namespace AdBlock {
+namespace AdBlock
+{
 struct AdBlockResult;
 class ADBLOCKLIB_EXPORT AdBlockBlockableItemsWidget : public QWidget
 {
@@ -30,11 +32,11 @@ public:
         Media,
         Popup,
 
-        MaxTypeElement
+        MaxTypeElement,
     };
 
     explicit AdBlockBlockableItemsWidget(QWidget *parent = nullptr);
-    ~AdBlockBlockableItemsWidget();
+    ~AdBlockBlockableItemsWidget() override;
 
     void setAdblockResult(const QVector<AdBlock::AdBlockResult> &result);
     void saveFilters();
@@ -52,10 +54,10 @@ private:
     enum BlockType {
         FilterValue = 0,
         Url,
-        Type
+        Type,
     };
     enum TypeItem {
-        Element = Qt::UserRole + 1
+        Element = Qt::UserRole + 1,
     };
 
     void writeConfig();
