@@ -1,22 +1,22 @@
 /* ============================================================
-*
-* This file is a part of the rekonq project
-*
-* SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
-* based on code from rekonq
-* SPDX-FileCopyrightText: 2010-2012 Andrea Diamantini <adjam7 at gmail dot com>
-*
-*
-* SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
-*
-* ============================================================ */
+ *
+ * This file is a part of the rekonq project
+ *
+ * SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+ * based on code from rekonq
+ * SPDX-FileCopyrightText: 2010-2012 Andrea Diamantini <adjam7 at gmail dot com>
+ *
+ *
+ * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+ *
+ * ============================================================ */
 
 // Self Includes
 #include "adblocksettingwidget.h"
-#include "ui_settings_adblock.h"
-#include "globalsettings_webengineurlinterceptoradblock.h"
 #include "adblockaddsubscriptiondialog.h"
 #include "adblockinterceptor_debug.h"
+#include "globalsettings_webengineurlinterceptoradblock.h"
+#include "ui_settings_adblock.h"
 
 #include "adblockmanager.h"
 #include "adblockshowlistdialog.h"
@@ -31,16 +31,16 @@ using namespace PimCommon::ConfigureImmutableWidgetUtils;
 
 #include <QIcon>
 
-#include <KMessageBox>
 #include <KLocalizedString>
+#include <KMessageBox>
 #include <QWhatsThisClickedEvent>
 
 // Qt Includes
-#include <QWhatsThis>
-#include <QPointer>
-#include <QStandardPaths>
 #include <KIO/JobUiDelegate>
 #include <KIO/OpenUrlJob>
+#include <QPointer>
+#include <QStandardPaths>
+#include <QWhatsThis>
 #include <adblocksubscription.h>
 
 using namespace AdBlock;
@@ -139,13 +139,16 @@ void AdBlockSettingWidget::slotInfoLinkActivated(const QString &url)
     Q_UNUSED(url)
 
     const QString href = QStringLiteral("https://adblockplus.org/en/filters");
-    const QString hintHelpString = i18n("<qt><p>Enter an expression to filter. Filters can be defined as either:"
-                                        "<ul><li>a shell-style wildcard, e.g. <tt>http://www.example.com/ads*</tt>, "
-                                        "the wildcards <tt>*?[]</tt> may be used</li>"
-                                        "<li>a full regular expression by surrounding the string with '<tt>/</tt>', "
-                                        "e.g. <tt>/\\/(ad|banner)\\./</tt></li></ul>"
-                                        "<p>Any filter string can be preceded by '<tt>@@</tt>' to whitelist (allow) any matching URL, "
-                                        "which takes priority over any blacklist (blocking) filter.<br><a href=\'%1\'>%2</a></qt>", href, i18n("More information"));
+    const QString hintHelpString = i18n(
+        "<qt><p>Enter an expression to filter. Filters can be defined as either:"
+        "<ul><li>a shell-style wildcard, e.g. <tt>http://www.example.com/ads*</tt>, "
+        "the wildcards <tt>*?[]</tt> may be used</li>"
+        "<li>a full regular expression by surrounding the string with '<tt>/</tt>', "
+        "e.g. <tt>/\\/(ad|banner)\\./</tt></li></ul>"
+        "<p>Any filter string can be preceded by '<tt>@@</tt>' to whitelist (allow) any matching URL, "
+        "which takes priority over any blacklist (blocking) filter.<br><a href=\'%1\'>%2</a></qt>",
+        href,
+        i18n("More information"));
 
     QWhatsThis::showText(QCursor::pos(), hintHelpString, this);
 }
@@ -153,7 +156,7 @@ void AdBlockSettingWidget::slotInfoLinkActivated(const QString &url)
 bool AdBlockSettingWidget::event(QEvent *event)
 {
     if (event->type() == QEvent::WhatsThisClicked) {
-        auto *clicked = static_cast<QWhatsThisClickedEvent *>(event);
+        auto clicked = static_cast<QWhatsThisClickedEvent *>(event);
         KIO::OpenUrlJob *job = new KIO::OpenUrlJob(QUrl(clicked->href()));
         job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
         job->start();
@@ -188,9 +191,8 @@ void AdBlockSettingWidget::removeRule()
     if (select.isEmpty()) {
         return;
     }
-    if (KMessageBox::No == KMessageBox::warningYesNo(this,
-                                                     i18np("Do you want to remove this rule?", "Do you want to remove these rules?", select.count()),
-                                                     i18n("Remove"))) {
+    if (KMessageBox::No
+        == KMessageBox::warningYesNo(this, i18np("Do you want to remove this rule?", "Do you want to remove these rules?", select.count()), i18n("Remove"))) {
         return;
     }
     for (QListWidgetItem *item : select) {
@@ -227,7 +229,7 @@ void AdBlockSettingWidget::doLoadFromGlobalSettings()
         const QString url = subscription->url().toString();
         const QString name = subscription->title();
         if (!url.isEmpty()) {
-            auto *subItem = new AdBlockListwidgetItem(mUi->automaticFiltersListWidget);
+            auto subItem = new AdBlockListwidgetItem(mUi->automaticFiltersListWidget);
             subItem->setFlags(Qt::ItemIsEnabled | Qt::ItemIsUserCheckable | Qt::ItemIsSelectable | Qt::ItemIsDragEnabled);
             subItem->setSubscription(subscription);
             if (subscription->enabled()) {
@@ -238,11 +240,11 @@ void AdBlockSettingWidget::doLoadFromGlobalSettings()
 
             subItem->setData(UrlList, url);
             subItem->setText(name);
-        } else { //Custom .
+        } else { // Custom .
             mCustomSubscription = subscription;
             mBlockUpdate = true;
             for (AdBlockRule *rule : subscription->allRules()) {
-                auto *subItem = new QListWidgetItem(mUi->manualFiltersListWidget);
+                auto subItem = new QListWidgetItem(mUi->manualFiltersListWidget);
                 subItem->setFlags(Qt::ItemIsEnabled | Qt::ItemIsUserCheckable | Qt::ItemIsSelectable | Qt::ItemIsDragEnabled | Qt::ItemIsEditable);
                 subItem->setCheckState(rule->isEnabled() ? Qt::Checked : Qt::Unchecked);
                 subItem->setText(rule->filter());
@@ -310,7 +312,7 @@ void AdBlockSettingWidget::slotAddFilter()
         QString url;
         dlg->selectedList(name, url);
         if (AdBlockSubscription *subscription = AdblockManager::self()->addSubscription(name, url)) {
-            auto *subItem = new AdBlockListwidgetItem(mUi->automaticFiltersListWidget);
+            auto subItem = new AdBlockListwidgetItem(mUi->automaticFiltersListWidget);
             subItem->setFlags(Qt::ItemIsEnabled | Qt::ItemIsUserCheckable | Qt::ItemIsSelectable | Qt::ItemIsDragEnabled);
             subItem->setCheckState(Qt::Checked);
             subItem->setText(name);
@@ -396,13 +398,13 @@ void AdBlockSettingWidget::slotImportFilters()
 
 void AdBlockSettingWidget::addManualFilter(const QString &text, const QStringList &excludeRules)
 {
-    auto *rule = new AdBlockRule(text, mCustomSubscription);
+    auto rule = new AdBlockRule(text, mCustomSubscription);
     if (excludeRules.contains(text)) {
         rule->setEnabled(false);
     }
     const int offset = mCustomSubscription->addRule(rule);
     if (offset >= 0) {
-        auto *subItem = new QListWidgetItem(mUi->manualFiltersListWidget);
+        auto subItem = new QListWidgetItem(mUi->manualFiltersListWidget);
         subItem->setFlags(Qt::ItemIsEnabled | Qt::ItemIsUserCheckable | Qt::ItemIsSelectable | Qt::ItemIsDragEnabled | Qt::ItemIsEditable);
         subItem->setCheckState(excludeRules.contains(text) ? Qt::Unchecked : Qt::Checked);
         subItem->setText(text);
