@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -9,7 +9,8 @@
 
 #include <QWidget>
 class QWebEngineView;
-namespace AdBlock {
+namespace AdBlock
+{
 struct AdBlockResult;
 }
 
@@ -18,7 +19,7 @@ class AdblockBlockableElementGui : public QWidget
     Q_OBJECT
 public:
     explicit AdblockBlockableElementGui(QWidget *parent = nullptr);
-    ~AdblockBlockableElementGui();
+    ~AdblockBlockableElementGui() override;
 
 public Q_SLOTS:
     void slotSearchAdblock();
