@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,9 +7,10 @@
 #ifndef DONOTTRACKPLUGINURLINTERCEPTOR_H
 #define DONOTTRACKPLUGINURLINTERCEPTOR_H
 
-#include <WebEngineViewer/NetworkPluginUrlInterceptor>
 #include <QVariant>
-namespace WebEngineViewer {
+#include <WebEngineViewer/NetworkPluginUrlInterceptor>
+namespace WebEngineViewer
+{
 class NetworkPluginUrlInterceptorInterface;
 }
 class DoNotTrackPluginUrlInterceptor : public WebEngineViewer::NetworkPluginUrlInterceptor
