@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -8,7 +8,8 @@
 #define SELECTIMAPFOLDERDIALOG_H
 
 #include <QDialog>
-namespace KSieveUi {
+namespace KSieveUi
+{
 class SieveImapAccountSettings;
 }
 class SelectImapFolderWidget;
@@ -17,9 +18,9 @@ class SelectImapFolderDialog : public QDialog
     Q_OBJECT
 public:
     explicit SelectImapFolderDialog(const KSieveUi::SieveImapAccountSettings &account, QWidget *parent = nullptr);
-    ~SelectImapFolderDialog();
+    ~SelectImapFolderDialog() override;
 
-    QString selectedFolderName() const;
+    Q_REQUIRED_RESULT QString selectedFolderName() const;
 
 private:
     void slotEnabledNewFolder(bool enabled);
