@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -10,7 +10,8 @@
 #include <QObject>
 class KDescendantsProxyModel;
 class QAbstractProxyModel;
-namespace KSieveUi {
+namespace KSieveUi
+{
 class SieveImapAccountSettings;
 }
 class SelectImapLineEditCompleterModel : public QObject
@@ -18,9 +19,10 @@ class SelectImapLineEditCompleterModel : public QObject
     Q_OBJECT
 public:
     explicit SelectImapLineEditCompleterModel(const KSieveUi::SieveImapAccountSettings &account, QObject *parent = nullptr);
-    ~SelectImapLineEditCompleterModel();
+    ~SelectImapLineEditCompleterModel() override;
 
     Q_REQUIRED_RESULT QAbstractProxyModel *completerModel() const;
+
 private:
     KDescendantsProxyModel *const mFlatProxy;
 };
