@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,10 +7,11 @@
 #ifndef SELECTIMAPLOADFOLDERSJOB_H
 #define SELECTIMAPLOADFOLDERSJOB_H
 
+#include <KSieveUi/SieveImapAccountSettings>
 #include <QObject>
 #include <kimap/listjob.h>
-#include <KSieveUi/SieveImapAccountSettings>
-namespace KIMAP {
+namespace KIMAP
+{
 class Session;
 }
 
@@ -22,11 +23,11 @@ class SelectImapLoadFoldersJob : public QObject
     Q_OBJECT
 public:
     enum Roles {
-        PathRole = Qt::UserRole + 1
+        PathRole = Qt::UserRole + 1,
     };
 
     explicit SelectImapLoadFoldersJob(QStandardItemModel *model, QObject *parent = nullptr);
-    ~SelectImapLoadFoldersJob();
+    ~SelectImapLoadFoldersJob() override;
 
     void start();
 
@@ -37,7 +38,7 @@ Q_SIGNALS:
 
 private:
     void slotLoginDone(KJob *job);
-    void slotMailBoxesReceived(const QList<KIMAP::MailBoxDescriptor> &mailBoxes, const QList<QList<QByteArray> > &flags);
+    void slotMailBoxesReceived(const QList<KIMAP::MailBoxDescriptor> &mailBoxes, const QList<QList<QByteArray>> &flags);
     void slotReloadRequested();
     void slotFullListingDone(KJob *job);
 
