@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -13,7 +13,7 @@ class RegExpEditorWidget : public QWidget
     Q_OBJECT
 public:
     explicit RegExpEditorWidget(QWidget *parent = nullptr);
-    ~RegExpEditorWidget() = default;
+    ~RegExpEditorWidget() override = default;
 };
 
 #endif // REGEXPEDITORWIDGET_H
